#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/ioctl.h>
#include <net/if.h>
#include <netinet/in.h>
#include <arpa/inet.h>

#include "crypto0.h"
int main(int argc, char **argv)
{
    char *ifname = "crypto";
    char *prgname = argv[0];
    char *s;
    int sock = socket(AF_INET, SOCK_RAW, IPPROTO_RAW);
    struct crypto_userinfo info;
    struct ifreq req;

    if (sock < 0) {
        fprintf(stderr, "%s: socket(): %s\n", prgname, strerror(errno));
        exit(1);
    }

    strcpy(req.ifr_name, ifname);

    /* check that the insane interface exists */
    if ( ioctl(sock, SIOCGIFFLAGS, &req) < 0 ) {
	fprintf(stderr, "%s: %s: %s", prgname, ifname, strerror(errno));
	if (errno == ENODEV)
	    fprintf(stderr, " (did you load the module?)");
	putc('\n', stderr);
	exit(1);
    }

    switch(argc) {
	case 1: /* get information */
	    req.ifr_data = (caddr_t)&info;
	    if (ioctl(sock, SIOCCRYPTOGETINFO, &req)<0) {
		fprintf(stderr, "%s: ioctl(INSANEGETINFO): %s\n", prgname,
			strerror(errno));
		exit(1);
	    }
	    printf("slave:     %s\n", info.name);
	    break;

        case 2:

	    /* The first argument is the slave, then the mode, then args */
	    req.ifr_data = (caddr_t)&info;
	    strncpy(info.name, argv[1], CRYPTO_NAMELEN);

	    /* ok, now pass this information to the device */
	    if (ioctl(sock, SIOCCRYPTOSETINFO, &req)<0) {
		fprintf(stderr, "%s: ioctl(CRYPTOSETINFO): %s\n", prgname,
			strerror(errno));
		exit(1);
	    }
	    break;

        default:
	    fprintf(stderr, "%s: Wrong number of arguments\n", prgname);
	    exit(1);
    }
    return 0;
}
